# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-10-13 13:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('iprestrict', '0005_add_reverse_ipgroup'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ipgroup',
            name='type',
            field=models.CharField(choices=[('location', 'Location based'), ('range', 'Range based')], default='range', max_length=10),
        ),
        migrations.AlterField(
            model_name='iplocation',
            name='country_codes',
            field=models.CharField(help_text='Comma-separated list of 2 character country codes', max_length=2000),
        ),
        migrations.AlterField(
            model_name='rule',
            name='action',
            field=models.CharField(choices=[('A', 'ALLOW'), ('D', 'DENY')], default='D', max_length=1),
        ),
    ]
